package console

import (
	"bufio"
	"context"
	"doc-service/domain/entity/serversitemicros/docserverproject"
	service2 "doc-service/domain/repository"
	"doc-service/infra/db"
	"fmt"
	"gitlab.galaxy-immi.com/Backend-group/go-com/third/log"
	"os"
	"strings"
	"time"
)

func DoAliData() {
	fmt.Println("开始刷新请求...")
	ctx := context.Background()
	// 启动一个协程来执行定时任务 20秒一次
	ticker := time.NewTicker(5 * time.Second)
	defer ticker.Stop()

	go func() {
		for {
			select {
			case <-ticker.C:
				i := toDoData(ctx)
				if i == 0 {
					fmt.Println("没有数据: " + time.Now().Format("2006-01-02 15:04:05"))
				}
			}
		}
	}()

	// 监听命令行输入
	reader := bufio.NewReader(os.Stdin)
	for {
		text, _ := reader.ReadString('\n')
		text = strings.TrimSpace(text)

		if text == "exit" {
			fmt.Println("Exiting process...")
			os.Exit(0)
		}
	}
}

//获取数据

func toDoData(c context.Context) int8 {
	projectData, err := db.GetServerSiteMicrosDB().DocServerProject.Query().Where(
		docserverproject.StatusEQ(0),
	).All(c)

	if err != nil {
		return 0
	}

	if len(projectData) <= 0 {
		return 0
	}

	for _, item := range projectData {
		ali := DoConversionToAli(c, item.ID)
		if ali {
			_, errUpdate := db.GetServerSiteMicrosDB().DocServerProject.UpdateOneID(item.ID).SetStatus(1).Save(c)
			if errUpdate != nil {
				log.Info("修改状态出错" + errUpdate.Error())
				continue
			}
		}
		log.Info("脚本请求阿里文件转换完成: " + string(item.ID))
		fmt.Printf("脚本请求阿里文件转换完成:   %d\n", item.ID)
	}
	return 1
}

// 执行文件转换（脚本使用）
func DoConversionToAli(c context.Context, projectId int32) bool {
	ConversionInfo, infoErr := db.GetServerSiteMicrosDB().DocServerProject.Get(c, projectId)
	if infoErr != nil {
		return false
	}
	IsPrivate := true
	if ConversionInfo.IsPrivate == 0 {
		IsPrivate = false
	}

	request := &service2.DoConversionRequest{
		ProjectName: ConversionInfo.ProjectName,
		SourceType:  ConversionInfo.SourceType,
		TargetType:  ConversionInfo.TargetType,
		SourceURI:   *ConversionInfo.SourceURL,
		TargetURI:   *ConversionInfo.TargetURL,
		IsPrivate:   IsPrivate,
	}

	//创建项目
	createErr := service2.NewConversion().CreateProject()
	if createErr != nil {
		log.Info("创建项目出错" + createErr.Error())
		return false
	}

	//执行转换
	result, errs := service2.NewConversion().Conversion(request)
	if errs != nil {
		log.Info("转换出错" + errs.Error())
		return false
	}
	taskId := result["body"].(map[string]interface{})["TaskId"].(string)
	//修改taskId
	_, errsInfo := db.GetServerSiteMicrosDB().DocServerProject.UpdateOneID(projectId).SetTaskID(taskId).Save(c)
	if errsInfo != nil {
		log.Info("入库出错" + errsInfo.Error())
		return false
	}
	return true
}
